Documentation
¶
Overview ¶
Package yang is a generated package which contains definitions of structs which represent a YANG schema. The generated schema can be compressed by a series of transformations (compression was false in this case).
This package was generated by /Users/hiroki.shirokura/go/pkg/mod/github.com/openconfig/ygot@v0.29.18/genutil/names.go using the following YANG input files:
- ../../yang/linux-agent.yang
Imported modules were sourced from:
- yang/...
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Binary ¶
type Binary []byte
Binary is a type that is used for fields that have a YANG type of binary. It is used such that binary fields can be distinguished from leaf-lists of uint8s (which are mapped to []uint8, equivalent to []byte in reflection).
type Device ¶
type Device struct {
Interfaces LinuxAgent_Interfaces `json:"interfaces"`
}
Device represents the /device YANG schema element.
type LinuxAgent_Interfaces ¶
type LinuxAgent_Interfaces struct {
Interface []LinuxAgent_Interfaces_Interface `json:"interface"`
}
LinuxAgent_Interfaces represents the /linux-agent/interfaces YANG schema element.
type LinuxAgent_Interfaces_Interface ¶
type LinuxAgent_Interfaces_Interface struct {
Address *string `json:"address"`
Enabled *bool `json:"enabled"`
Name *string `json:"name"`
}
LinuxAgent_Interfaces_Interface represents the /linux-agent/interfaces/interface YANG schema element.